#
# spec file for package ipxe
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# Based on the Fedora, Debian and Arch Linux packages

Name:           ipxe
Version:        1.0.0+git20180203.546dd51d
Release:        4.1
Summary:        A Network Boot Firmware
License:        GPL-2.0
Group:          System/Boot
Url:            http://ipxe.org/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  binutils-devel
BuildRequires:  /usr/bin/mkisofs
BuildRequires:  perl
BuildRequires:  syslinux
BuildRequires:  xz-devel
# ix86 does not have a cross-x86_64 gcc available so it can't build
# the x86_64 ipxe code. As a result of which, the support for ix86
# is more limited.
ExclusiveArch:  %{ix86} x86_64

%description
iPXE is a network bootloader. It provides a direct
replacement for proprietary PXE ROMs, with many extra features such as
DNS, HTTP, iSCSI, etc.

%package bootimgs
Summary:        Network boot loader images in bootable USB, CD, floppy and GRUB formats
Group:          Development/Tools/Other
BuildArch:      noarch

%description bootimgs
iPXE is a network bootloader. It provides a direct
replacement for proprietary PXE ROMs, with many extra features such as
DNS, HTTP, iSCSI, etc.

This package contains the iPXE boot images in USB, CD, floppy, and PXE
UNDI formats. EFI is supported, too.

%prep
%setup -q

%build
cd src

make_ipxe() {
    make %{?_smp_mflags} V=1 \
        VERSION=%{version} "$@"
}

make_ipxe bin-i386-efi/ipxe.efi
%ifarch x86_64
# ix86 can't cross-compile
make_ipxe bin-x86_64-efi/ipxe.efi
%endif

make_ipxe bin/undionly.kpxe bin/ipxe.{dsk,iso,usb,lkrn}

%install
mkdir -p %{buildroot}/%{_datadir}/%{name}/
mkdir -p %{buildroot}/%{_datadir}/%{name}.efi/

install -D -m0644 src/bin/undionly.kpxe %{buildroot}/%{_datadir}/%{name}/
install -D -m0644 src/bin/ipxe.{iso,usb,dsk,lkrn} %{buildroot}/%{_datadir}/%{name}/
install -D -m0644 src/bin-i386-efi/ipxe.efi %{buildroot}/%{_datadir}/%{name}/ipxe-i386.efi
%ifarch x86_64
install -D -m0644 src/bin-x86_64-efi/ipxe.efi %{buildroot}/%{_datadir}/%{name}/ipxe-x86_64.efi
%endif

%files bootimgs
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/ipxe.iso
%{_datadir}/%{name}/ipxe.usb
%{_datadir}/%{name}/ipxe.dsk
%{_datadir}/%{name}/ipxe.lkrn
%{_datadir}/%{name}/ipxe-i386.efi
%ifarch x86_64
%{_datadir}/%{name}/ipxe-x86_64.efi
%endif
%{_datadir}/%{name}/undionly.kpxe
%doc COPYING COPYING.GPLv2 COPYING.UBDL

%changelog
* Sun Feb 18 2018 jengelh@inai.de
- Trim redundancies. Do mention presence of EFI programs.
* Fri Feb 16 2018 dmueller@suse.com
- reduce build requires
- update license
* Fri Feb 16 2018 bwiedemann@suse.de
- Drop upstream 0001-arch-i386-Check-for-no-pie-gcc-option-as-well.patch
- Update to version 1.0.0+git20180203.546dd51d:
  * [intel] Work around broken reset mechanism in i219 devices
  * [xhci] Assume an invalid PSI table if any invalid PSI value is observed
  * [ena] Fix spurious uninitialised variable warning on older versions of gcc
  * [netdevice] Make netdev_irq_enabled() independent of netdev_irq_supported()
  * [tg3] Add support for SerDes PHY initialization
  * [skel] Remove MII interface
  * [ena] Add driver for Amazon ENA virtual function NIC
  * [build] Avoid use of "ld --oformat binary"
  * [legal] Add missing FILE_LICENCE declarations
  * [image] Omit URI query string and fragment from download progress messages
  * [http] Report unsuccessful response status lines at DBGVL_LOG
  * [http] Include error messages for 4xx and 5xx response codes
  * [xen] Skip probing of any unsupported device types
  * [intel] Add PCI device ID for X550-T2
  * [http] Add support for NTLM authentication
  * [http] Handle parsing of WWW-Authenticate header within authentication scheme
  * [http] Gracefully handle offers of multiple authentication schemes
  * [ntlm] Add support for NTLM authentication mechanism
  * [crypto] Add MD4 message digest algorithm
  * [crypto] Eliminate repetitions in MD5 round constant table
  * [crypto] Fix endianness typo in comment
  * [efi] Allow for building with older versions of elf.h system header
  * [efi] Accept (and ignore) R_ARM_V4BX relocations
  * [crypto] Fail fast if cross-certificate source is empty
  * [efi] Inhibit our driver Start() method during disconnection attempts
  * [build] Exclude selected directories from Secure Boot builds
  * [efi] Continue to connect remaining handles after connection errors
  * [exanic] Add PCI device ID for another X40 variant
  * [exanic] Power up optical PHYs (if present)
  * [dns] Ensure DNS names are NUL-terminated when used as diagnostic strings
  * [efi] Match behaviour of SnpDxe for truncated received packets
  * [efi] Check buffer length for packets retrieved via our SNP protocol
  * [dns] Report current DNS query as job progress status message
  * [resolv] Use pass-through interfaces for name resolution multiplexer
  * [netdevice] Add "hwaddr" setting
  * [peerdist] Gather and report peer statistics during download
  * [monojob] Display job status message, if present
  * [downloader] Allow underlying downloads to provide detailed job progress
  * [job] Allow jobs to report an arbitrary status message
  * [monojob] Check for job progress only once per timer tick
  * [netdevice] Cancel all pending transmissions on any transmit error
  * [efi] Raise TPL when calling UNDI entry point
  * [linux] Impose receive quota on tap driver
  * [malloc] Avoid false positive warnings from valgrind
  * [romprefix] Avoid unaligned accesses within ROM headers
  * [intel] Add various PCI device IDs
  * [shell] Enable "shell" command even when BANNER_TIMEOUT is zero
  * [hyperv] Do not steal ownership from the Gen 2 UEFI firmware
  * [acpi] Fix spurious uninitialised-variable warning on some gcc versions
  * [acpi] Compute and check checksum for ACPI tables
  * [build] Fix ARM32 EFI builds with current EDK2 headers
  * [build] Fix use of inline assembly on GCC 4.8 ARM64 builds
  * [build] Conditionalise use of -mabi=lp64 for ARM64 builds
  * [efi] Enumerate PCI BARs in same order as SnpDxe
  * [lan78xx] Add driver for Microchip LAN78xx USB Ethernet NICs
  * [smsc75xx] Expose functionality shared with LAN78xx devices
  * [smscusb] Allow for alternative PHY register layouts
  * [smscusb] Move non-inline register access functions to smscusb.c
  * [virtio] Support VIRTIO_NET_F_IOMMU_PLATFORM
  * [smscusb] Add ability to read MAC address from OTP
  * [smsc75xx] Use common SMSC USB device functionality
  * [smsc95xx] Use common SMSC USB device functionality
  * [smscusb] Abstract out common SMSC USB device functionality
  * [intel] Add support for I219-V in 7th Gen Intel NUC
  * [tls] Support RFC5746 secure renegotiation
  * [mucurses] Avoid potential division by zero
  * [usb] Use non-zero language ID to retrieve strings
  * [exanic] Add driver for Exablaze ExaNIC cards
  * [crypto] Expose pem_asn1() for use with non-image data
  * [crypto] Provide asn1_built() to construct a cursor from a builder
  * [crypto] Expose asn1_grow()
  * [crypto] Expose RSA_CTX_SIZE constant
  * [cpuid] Allow input %%ecx value to be specified
  * [ecm] Display invalid MAC address strings in debug messages
  * [build] Use -no-pie on newer versions of gcc
  * [intel] Add INTEL_NO_PHY_RST for I219-V
  * [usb] Allow for USB network devices with no interrupt endpoint
  * [hdprefix] Avoid attempts to read beyond the end of the disk
  * [syslog] Handle backspace characters
* Sun May 28 2017 mchandras@suse.de
- Update snapshot to ipxe-1.0.0+git20170523.356f6c1b. Some of the changes are:
  * [acpi] Expose ACPI tables via settings mechanism
  * [efi] Provide access to ACPI tables
  * [acpi] Make acpi_find_rsdt() a per-platform method
  * [efi] Prevent EFI code from being linked in to non-EFI builds
  * [block] Provide abstraction to allow system to be quiesced
  * [intel] Do not enable ASDE on i350 backplane NIC
  * [block] Allow use of a non-default EFI SAN boot filename
  * [thunderx] Use ThunderxConfigProtocol to obtain board configuration
  * [linux] Fix building with kernel 4.11 headers
  * [build] Avoid implicit-fallthrough warnings on GCC 7
  * [http] Notify data transfer interface when underlying connection is ready
  * [block] Describe all SAN devices via ACPI tables
  * [block] Add basic multipath support
  * [vxge] Fix use of stale I/O buffer on error path
  * [pcnet32] Eliminate redundant register read
  * [rtl818x] Fix resource leak on error path
  * [sis190] Avoid NULL pointer dereference
  * [w89c840] Avoid potential array overrun
  * [tcp] Use correct length for memset()
  * [usb] Use correct length for memcpy()
  * [ath] Add missing break statements
  * [infiniband] Return status code from ib_create_mi()
  * [infiniband] Return status code from ib_create_cq() and ib_create_qp()
  * [mucurses] Attempt to fix resource leaks
  * [mucurses] Attempt to fix keypress processing logic
  * [mucurses] Attempt to fix test for empty string
  * [802.11] Remove redundant NULL pointer check after dereference
  * [nfs] Fix double free bug on error path
  * [xfer] Ensure va_end() is called on failure path
  * [arbel] Avoid potential integer overflow when calculating memory mappings
  * [hermon] Avoid potential integer overflow when calculating memory mappings
  * [thunderx] Don't disable NIC when exiting from iPXE
  * [thunderx] Fix hardware deinitialization
  * [http] Cleanly shut down potentially looped interfaces
  * [intel] Add INTEL_NO_PHY_RST for I219-LM (2)
  * [int13] Test correct return status from INT 13 calls
  * [int13] Avoid potential division by zero
  * [pic8259] Fix definitions for "read IRR" and "read ISR" commands
  * [cloud] Show CPU vendor and model in example cloud boot scripts
  * [netdevice] Allow MTU to be changed at runtime
  * [virtio] Use host-specified MTU when available
  * [virtio] Use separate RX and TX empty header buffers
  * [virtio] Remove queue size limit in legacy virtio
  * [virtio] Simplify virtqueue shutdown
  * [virtio] Cap queue size to MAX_QUEUE_NUM
- Add patch to enable -no-pie when building i386 binaries. This was only
  triggered recently since the gcc-7.1.1 started using -fpie by default
  * 0001-arch-i386-Check-for-no-pie-gcc-option-as-well.patch
* Thu Sep  1 2016 mchandras@suse.de
- Initial commit. We only build and package the iPXE boot images for now
